/*
 *  xwxapt: An application to decode APT signals from weather
 *  satellites and produce an image of the weather.
 *
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef IMAGE_H
#define IMAGE_H		1

#include "common.h"
#include "interface.h"
#include "support.h"

/* Definitions for NOAA image processing */
#define NOAA_PIXEL_SAMPLES		       14 /* DSP samples used for an image pixel*/
#define NOAA_IMAGE_WIDTH              748 /* Width in pixels of images produced */
#define NOAA_SYNC_CHA_SPACE           540 /* Space between ch A sync and image  */
#define NOAA_CHA_CHB_SPACE           1522 /* Space between ch A & B, in samples */
#define NOAA_SYNC_PULSES	 		    7 /* Number of pulses in the sync train */
#define NOAA_SYNC_SAMPLES	           23 /* Carrier samples per 1/2 sync cycle */
#define NOAA_SYNC_TAIL			       90 /* Sync train tail length, in samples */
#define NOAA_SYNC_FIFO_SIZE           412 /* Size of sync detector samples fifo */
#define NOAA_SYNC_LOWER_THRESH    2000000 /* Sync train detector lower threshold*/
#define NOAA_SYNC_UPPER_THRESH    3100000 /* Sync train detector upper threshold*/
#define NOAA_SYNC_REF                 750 /* Required position of sync train    */
#define NOAA_SCALE_FACTOR              28 /* Factor to keep pixel values < 255  */
#define NOAA_CARRIER_MAX            35000 /* Max 2.4kHz carrier-level required  */

/* Definitions for Meteor image processing */
#define METEOR_PIXEL_SAMPLES	       24 /* DSP samples used for an image pixel*/
#define METEOR_IMAGE_WIDTH            800 /* Width in pixels of images produced */
#define METEOR_SYNC_IMAGE_SPACE       648 /* Space between sync and image start */
#define METEOR_SYNC_PULSES		        5 /* Number of pulses in the sync train */
#define METEOR_SYNC_MARK		       13 /* Number of carrier samples in mark  */
#define METEOR_SYNC_SPACE		       27 /* Number of carrier samples in space */
#define METEOR_SYNC_FIFO_SIZE         200 /* Size of sync detector samples fifo */
#define METEOR_SYNC_LOWER_THRESH  2000000 /* Sync train detector lower threshold*/
#define METEOR_SYNC_UPPER_THRESH  2500000 /* Sync train detector upper threshold*/
#define METEOR_SYNC_REF               648 /* Required position of sync train    */
#define METEOR_SCALE_FACTOR            12 /* Factor to keep pixel values < 255  */
#define METEOR_CARRIER_MAX            160 /* Max 2.4kHz carrier-level required  */

/* Satellite type definitions */
#define NOAA                    0 /* NOAA type APT format   */
#define METEOR                  1 /* METEOR type APT format */
#define NUM_SATS                2 /* Number of APT formats supported */
#define SAT_NAMES  				"NOAA", "Meteor"
#define SYNC_REFS				NOAA_SYNC_REF, METEOR_SYNC_REF

/* Color maps to use */
#define NOAA_A_COLORMAP 	0
#define NOAA_B_COLORMAP 	1
#define METEOR_COLORMAP 	2

#define BLACK_CUT_OFF		1 /* Black cut-off percentile for normalization */
#define WHITE_CUT_OFF		2 /* White cut-off percentile for normalization */

#endif

